import type { McpConfig } from '../types';
export { grepAppMcp } from './grep-app';
export { context7Mcp } from './context7';
export type McpName = 'grep_app' | 'context7';
export declare function createBuiltinMcps(disabledMcps?: string[]): Record<string, McpConfig>;
export declare function getMcp(name: McpName): McpConfig;
export declare function getAllMcps(): McpConfig[];
//# sourceMappingURL=index.d.ts.map